@@ -3,6 +3,7 @@ from os.path import abspath
 
 from .repl import REPL
 from .config import Config
+from .modes import list_modes
 
 def load_file(file_path):
   with open(file_path) as f:
@@ -23,7 +24,7 @@ def run(cmd, mode, thread, file, list):
     click.echo(ctx.get_help())
     return
 
-  if list:
+  if list or cmd == 'threads':
     for thread in get_threads(config_path):
       print(thread)
     return
@@ -57,6 +58,11 @@ def run(cmd, mode, thread, file, list):
     autofills=autofills,
   )
 
+  if cmd == 'modes':
+    for mode in list_modes():
+      print(mode)
+    return
+
   repl.run()
 
 def get_threads(config_path):
