@@ -4,14 +4,16 @@ from .mode import BaseMode, register_mode
 class CowsayMode(BaseMode):
 
   title = 'Cow'
-  visible = True
 
   def ask(self, text):
     cow = f'```text\n{self.build_cow(text)}\n```'
     yield cow
 
   def stats(self):
-    return '( mooooo )'
+    return '( mood=moootastic )'
+
+  def print(self):
+    print('mooooooooooooooooooooooooooooooooooooooooooooooooooo')
 
   def build_cow(self, text):
     dialogue = f'< {text} >'
@@ -27,6 +29,3 @@ class CowsayMode(BaseMode):
                 ||     ||
 """
     return cow
-
-  def print(self):
-    print('mooooooooooooooooooooooooooooooooooooooooooooooooooo')
