@@ -9,11 +9,19 @@ def register_mode(name):
 def get_mode(name):
   return mode_registry[name]
 
+def list_modes(show_hidden=False):
+  modes = []
+  for name, mode in mode_registry.items():
+    if name != 'base' and mode.visible or show_hidden:
+      modes += [ name ]
+  modes.sort()
+  return modes
+
 @register_mode('base')
 class BaseMode:
 
-  username = ''
-  visible = False
+  title = ''
+  visible = True
 
   seed = ''
 
